==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/inc/lang/sk/lang.php <==
<?php
/**
 * Slovak language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Ondrej Vegh <ov@vsieti.sk> with help of the scholars from Zdruzena stredna skola polygraficka in Bratislava
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Upraviť stránku';
$lang['btn_source'] = 'Zobraziť zdroj stránky';
$lang['btn_show']   = 'Zobraziť stránku';
$lang['btn_create'] = 'Vytvoriť stránku';
$lang['btn_search'] = 'Hľadať';
$lang['btn_save']   = 'Uložiť';
$lang['btn_preview']= 'Náhľad';
$lang['btn_top']    = 'Hore';
$lang['btn_newer']  = '<< novšie';
$lang['btn_older']  = 'staršie >>';
$lang['btn_revs']   = 'Staršia verzia';
$lang['btn_recent'] = 'Posledné úpravy';
$lang['btn_upload'] = 'Priložiť';
$lang['btn_cancel'] = 'Storno';
$lang['btn_index']  = 'Index';
$lang['btn_secedit']= 'Upraviť';
$lang['btn_login']  = 'Prihlásiť sa';
$lang['btn_logout'] = 'Odhlásiť sa';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Aktualizovať';
$lang['btn_delete'] = 'Zmazať';
$lang['btn_back']   = 'Späť';
$lang['btn_backlink']    = "Spätné linky";
$lang['btn_backtomedia'] = 'Späť na výber média';
$lang['btn_subscribe']   = 'Posielať zmeny';
$lang['btn_unsubscribe'] = 'Neposielať zmeny';
$lang['btn_profile']    = 'Aktualizovať profil';
$lang['btn_reset']     = 'Zrušiť';
$lang['btn_resendpwd'] = 'Poslať nové heslo';

$lang['loggedinas'] = 'Prihlásený(á) ako';
$lang['user']       = 'Užívateľské meno';
$lang['pass']       = 'Heslo';
$lang['newpass']    = 'Nové heslo';
$lang['oldpass']    = 'Potvrď aktuálne heslo';
$lang['passchk']    = 'Ešte raz znovu';
$lang['remember']   = 'Zapamätaj si ma';
$lang['fullname']   = 'Celé meno';
$lang['email']      = 'E-Mail';
$lang['profile']    = 'Užívateľský profil';
$lang['register']   = 'Registrovať';
$lang['badlogin']   = 'Zadané užívateľské meno a heslo nie je správne.';
$lang['minoredit']  = 'Menšie zmeny';

$lang['regmissing'] = 'Musíte vyplniť všetky údaje.';
$lang['reguexists'] = 'Užívateľ s rovnakým menom je už zaregistrovaný.';
$lang['regsuccess'] = 'Užívateľský účet bol vytvorený a heslo zaslané mailom.';
$lang['regsuccess2']= 'Užívateľský účet bol vytvorený.';
$lang['regmailfail']= 'Zdá sa, že nastala chyba pri posielaní mailu s heslom. Skúste kontaktovať správcu.';
$lang['regbadmail'] = 'Zadaná mailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
$lang['regbadpass'] = 'Dve zadané heslá nie sú rovnaké, skúste prosím znovu.';
$lang['regpwmail']  = 'Vaše heslo do systému DokuWiki';
$lang['reghere']    = 'Nemáte uživateľský účet? Vytvorte si ho';

$lang['profna']       = 'Toto wiki nepodporuje zmenu profilu';
$lang['profnochange'] = 'Žiadne zmeny, nie je čo robiť.';
$lang['profnoempty']  = 'Prázdne meno, alebo e-mailová adresa nie sú povolené.';
$lang['profchanged']  = 'Užívateľský účet úspešne zmenený.';

$lang['pwdforget'] = 'Zabudli ste heslo? Získajte nové!';
$lang['resendna']  = 'Toto wiki nepodporuje znovuposielanie hesla.';
$lang['resendpwd'] = 'Pošli nové heslo pre';
$lang['resendpwdmissing'] = 'Prepáčte, musíte vyplniť všetky polia.';
$lang['resendpwdnouser']  = 'Prepáčte, nemôžeme nájsť zadaného užívateľa v databáza.';
$lang['resendpwdsuccess'] = 'Vaše nové heslo bolo zaslané na e-mail.';


$lang['txt_upload']   = 'Vyberte súbor ako prílohu';
$lang['txt_filename'] = 'Wiki meno (volitelné)';
$lang['txt_overwrt']  = 'Prepísať existujúci súbor';
$lang['lockedby']     = 'Práve zamknuté:';
$lang['lockexpire']   = 'Zámok vyprší:';
$lang['willexpire']   = 'Váš zámok pre editáciu za chvílu vyprší.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';

$lang['notsavedyet'] = 'Neuložené zmeny budú ztratené.\nChcete naozaj pokračovať?';
$lang['rssfailed']   = 'Nastala chyba pri vytváraní tohto RSS: ';
$lang['nothingfound']= 'Nič nenájdené.';

$lang['mediaselect'] = 'Výber dokumentu';
$lang['fileupload']  = 'Nahrávanie dokumentu';
$lang['uploadsucc']  = 'Prenos prebehol v poriadku';
$lang['uploadfail']  = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
$lang['uploadwrong'] = 'Priloženie súboru s takouto príponou není dovolené.';
$lang['uploadexist'] = 'Súbor skutočne existuje. Nie je čo robiť.';
$lang['deletesucc']  = 'Súbor "%s" bol zmazený.';
$lang['deletefail']  = '"%s" nie je možné zmazať - skontrolujte oprávnenia.';
$lang['mediainuse']  = 'Súbor "%s" nebol zmazaný - je stále používaný.';
$lang['namespaces']  = 'Menné priestory';
$lang['mediafiles']  = 'Dostupné súbory';

$lang['reference']   = 'Referencie pre';
$lang['ref_inuse']   = 'Súbor nemôže byť zmazaný, pretože je stále používaný nasledujúcimi stránkami:';
$lang['ref_hidden']  = 'Niektoré referencie sú na stránky pre ktoré nemáte právo na čítanie';

$lang['hits']       = '- počet výskytov';
$lang['quickhits']  = 'Zodpovedajúce stránky';
$lang['toc']        = 'Obsah';
$lang['current']    = 'aktualné';
$lang['yours']      = 'Vaša verzia';
$lang['diff']       = 'zobrazit rozdiely voči aktuálnej verzii';
$lang['line']       = 'Riadok';
$lang['breadcrumb'] = 'História';
$lang['lastmod']    = 'Posledná úprava';
$lang['by']         = 'od';
$lang['deleted']    = 'odstranené';
$lang['created']    = 'vytvorené';
$lang['restored']   = 'stará verzia bola obnovena';
$lang['summary']    = 'Komentár k úpravám';

$lang['mail_newpage'] = '[DokuWiki] nová stránka:';
$lang['mail_changed'] = '[DokuWiki] zmena stránky:';

$lang['nosmblinks'] = 'Odkazovanie na zdielané prostriedky Windows funguje len v Internet Explorer.\nAj napriek tomu tento odkaz môžete skopírovat a vložit inde.';

$lang['qb_alert']   = 'Vložte prosím text, ktorý chcete formátovať.\nTen bude pridaný na koniec dokumentu.';
$lang['qb_bold']    = 'Tučné';
$lang['qb_italic']  = 'Kurzíva';
$lang['qb_underl']  = 'Podčiarknutie';
$lang['qb_code']    = 'Neformátovať (zdrojový kód)';
$lang['qb_strike']  = 'Prečiarknutie';
$lang['qb_h1']      = 'Nadpis 1. úrovne';
$lang['qb_h2']      = 'Nadpis 2. úrovne';
$lang['qb_h3']      = 'Nadpis 3. úrovne';
$lang['qb_h4']      = 'Nadpis 4. úrovne';
$lang['qb_h5']      = 'Nadpis 5. úrovne';
$lang['qb_link']    = 'Interný odkaz';
$lang['qb_extlink'] = 'Externý odkaz';
$lang['qb_hr']      = 'Horizontálna linka';
$lang['qb_ol']      = 'Číslovaný zoznam';
$lang['qb_ul']      = 'Nečíslovaný zoznam';
$lang['qb_media']   = 'Vložiť obrázky alebo iné súbory';
$lang['qb_sig']     = 'Vložiť podpis';
$lang['qb_smileys'] = 'Smajlíky';
$lang['qb_chars']   = 'Špeciálne znaky';

$lang['del_confirm']= 'Zmazať túto položku?';
$lang['admin_register']= 'Pridaj nového užívateľa';

$lang['spell_start'] = 'Skontrolovať pravopis';
$lang['spell_stop']  = 'Úprava výsledku';
$lang['spell_wait']  = 'Prosím čakajte...';
$lang['spell_noerr'] = 'Žiadne chyby nenájdené';
$lang['spell_nosug'] = 'Žiadne doporučenia';
$lang['spell_change']= 'Zmena';

$lang['metaedit']    = 'Upraviť metainformácie';
$lang['metasaveerr'] = 'Zápis metainformácií zlyhal';
$lang['metasaveok']  = 'Metainformácie uložené';
$lang['img_backto']  = 'Späť na';
$lang['img_title']   = 'Titul';
$lang['img_caption'] = 'Popis';
$lang['img_date']    = 'Dátum';
$lang['img_fname']   = 'Názov súboru';
$lang['img_fsize']   = 'Veľkosť';
$lang['img_artist']  = 'Fotograf';
$lang['img_copyr']   = 'Kopírovacie práva';
$lang['img_format']  = 'Formát';
$lang['img_camera']  = 'Fotoaparát';
$lang['img_keywords']= 'Klúčové slová';

$lang['subscribe_success']  = 'Pridané %s do zoznamu objednávok pre %s';
$lang['subscribe_error']    = 'Chyba pri pridaní %s do zoznamu objednávok pre %s';
$lang['subscribe_noaddress']= 'Nie je žiadna e-mailová adresa priradená k vašemu menu,nemôžte byť pridaný do zoznamu objednávok';
$lang['unsubscribe_success']= 'Odobrané %s zo zoznamu objednávok pre %s';
$lang['unsubscribe_error']  = 'Chaba pri odobraní %s zo zoznamu objednávok pre %s';

/* auth.class language support */
$lang['authmodfailed']   = 'Užívateľská autentifikácia nie je možná. Prosím informujte  správcu tohto systému.';

/* mysql.class language support */
$lang['noMySQL']         = "MySQL rozšírenie pre PHP nenájdené. Prosím informujte  správcu tohto systému.";
$lang['noDatabase']      = "MySQL: Nie je možné vstúpiť do databázy '%d'. Prosím informujte  správcu tohto systému.";
$lang['noConnect']       = "MySQL: Nie je možné pripojiť sa k '%u@%s'. Prosím informujte  správcu tohto systému.";
$lang['joinGroupFailed'] = "Účet pre '%u' nie je vytvorený, pretože nie je možné pridať ho do skupiny '%g'.";
$lang['modUserFailed']   = "Nie je možné meniť údaje o užívateľovi. Prosím informujte  správcu tohto systému.";


//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/inc/lang/sk/lang.php <==
<?php
/**
 * Slovak language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Ondrej Vegh <ov@vsieti.sk> with help of the scholars from Zdruzena stredna skola polygraficka in Bratislava
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Upraviť stránku';
$lang['btn_source'] = 'Zobraziť zdroj stránky';
$lang['btn_show']   = 'Zobraziť stránku';
$lang['btn_create'] = 'Vytvoriť stránku';
$lang['btn_search'] = 'Hľadať';
$lang['btn_save']   = 'Uložiť';
$lang['btn_preview']= 'Náhľad';
$lang['btn_top']    = 'Hore';
$lang['btn_newer']  = '<< novšie';
$lang['btn_older']  = 'staršie >>';
$lang['btn_revs']   = 'Staršia verzia';
$lang['btn_recent'] = 'Posledné úpravy';
$lang['btn_upload'] = 'Priložiť';
$lang['btn_cancel'] = 'Storno';
$lang['btn_index']  = 'Index';
$lang['btn_secedit']= 'Upraviť';
$lang['btn_login']  = 'Prihlásiť sa';
$lang['btn_logout'] = 'Odhlásiť sa';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Aktualizovať';
$lang['btn_delete'] = 'Zmazať';
$lang['btn_back']   = 'Späť';
$lang['btn_backlink']    = "Spätné linky";
$lang['btn_backtomedia'] = 'Späť na výber média';
$lang['btn_subscribe']   = 'Posielať zmeny';
$lang['btn_unsubscribe'] = 'Neposielať zmeny';
$lang['btn_profile']    = 'Aktualizovať profil';
$lang['btn_reset']     = 'Zrušiť';
$lang['btn_resendpwd'] = 'Poslať nové heslo';
$lang['btn_draft']    = 'Upraviť koncept';
$lang['btn_recover']  = 'Obnoviť koncept';
$lang['btn_draftdel'] = 'Zmazať koncept';

$lang['loggedinas'] = 'Prihlásený(á) ako';
$lang['user']       = 'Užívateľské meno';
$lang['pass']       = 'Heslo';
$lang['newpass']    = 'Nové heslo';
$lang['oldpass']    = 'Potvrď aktuálne heslo';
$lang['passchk']    = 'Ešte raz znovu';
$lang['remember']   = 'Zapamätaj si ma';
$lang['fullname']   = 'Celé meno';
$lang['email']      = 'E-Mail';
$lang['profile']    = 'Užívateľský profil';
$lang['register']   = 'Registrovať';
$lang['badlogin']   = 'Zadané užívateľské meno a heslo nie je správne.';
$lang['minoredit']  = 'Menšie zmeny';
$lang['draftdate']  = 'Koncept automaticky uložený'; // full dformat date will be added

$lang['regmissing'] = 'Musíte vyplniť všetky údaje.';
$lang['reguexists'] = 'Užívateľ s rovnakým menom je už zaregistrovaný.';
$lang['regsuccess'] = 'Užívateľský účet bol vytvorený a heslo zaslané mailom.';
$lang['regsuccess2']= 'Užívateľský účet bol vytvorený.';
$lang['regmailfail']= 'Zdá sa, že nastala chyba pri posielaní mailu s heslom. Skúste kontaktovať správcu.';
$lang['regbadmail'] = 'Zadaná mailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
$lang['regbadpass'] = 'Dve zadané heslá nie sú rovnaké, skúste prosím znovu.';
$lang['regpwmail']  = 'Vaše heslo do systému DokuWiki';
$lang['reghere']    = 'Nemáte uživateľský účet? Vytvorte si ho';

$lang['profna']       = 'Toto wiki nepodporuje zmenu profilu';
$lang['profnochange'] = 'Žiadne zmeny, nie je čo robiť.';
$lang['profnoempty']  = 'Prázdne meno, alebo e-mailová adresa nie sú povolené.';
$lang['profchanged']  = 'Užívateľský účet úspešne zmenený.';

$lang['pwdforget'] = 'Zabudli ste heslo? Získajte nové!';
$lang['resendna']  = 'Toto wiki nepodporuje znovuposielanie hesla.';
$lang['resendpwd'] = 'Pošli nové heslo pre';
$lang['resendpwdmissing'] = 'Prepáčte, musíte vyplniť všetky polia.';
$lang['resendpwdnouser']  = 'Prepáčte, nemôžeme nájsť zadaného užívateľa v databáze.';
$lang['resendpwdbadauth'] = 'Prepáčte, tento autorizačný kód nie je platný. Uistite sa, či ste použili celý autorizačný odkaz.';
$lang['resendpwdconfirm'] = 'Autorizačný odkaz bol zaslaný na e-mail.';
$lang['resendpwdsuccess'] = 'Vaše nové heslo bolo zaslané na e-mail.';


$lang['txt_upload']   = 'Vyberte súbor ako prílohu';
$lang['txt_filename'] = 'Wiki meno (volitelné)';
$lang['txt_overwrt']  = 'Prepísať existujúci súbor';
$lang['lockedby']     = 'Práve zamknuté:';
$lang['lockexpire']   = 'Zámok vyprší:';
$lang['willexpire']   = 'Váš zámok pre editáciu za chvílu vyprší.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';

$lang['notsavedyet'] = 'Neuložené zmeny budú ztratené.\nChcete naozaj pokračovať?';
$lang['rssfailed']   = 'Nastala chyba pri vytváraní tohto RSS: ';
$lang['nothingfound']= 'Nič nenájdené.';

$lang['mediaselect'] = 'Výber dokumentu';
$lang['fileupload']  = 'Nahrávanie dokumentu';
$lang['uploadsucc']  = 'Prenos prebehol v poriadku';
$lang['uploadfail']  = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
$lang['uploadwrong'] = 'Priloženie súboru s takouto príponou není dovolené.';
$lang['uploadexist'] = 'Súbor skutočne existuje. Nie je čo robiť.';
$lang['deletesucc']  = 'Súbor "%s" bol zmazený.';
$lang['deletefail']  = '"%s" nie je možné zmazať - skontrolujte oprávnenia.';
$lang['mediainuse']  = 'Súbor "%s" nebol zmazaný - je stále používaný.';
$lang['namespaces']  = 'Menné priestory';
$lang['mediafiles']  = 'Dostupné súbory';

$lang['js']['keepopen']    = 'Po vybraní súboru ponechať okno otvorené';
$lang['js']['hidedetails'] = 'Skryť detaily';
$lang['mediausage']  = 'Pre odkázanie na súbor použite nasledujúcu syntax:';
$lang['mediaview']   = 'Zobraziť pôvodný súbor';
$lang['mediaroot']   = 'root';
$lang['mediaupload'] = 'Priložiť súbor do aktuálneho menného priestoru. Pre vytvorenie menného podpriestoru, pridajte jeho názov na začiatok wiki mena (oddelený dvojbodkou)';
$lang['mediaextchange'] = 'Prípona súboru bola zmenená z .%s na .%s!';

$lang['reference']   = 'Referencie pre';
$lang['ref_inuse']   = 'Súbor nemôže byť zmazaný, pretože je stále používaný nasledujúcimi stránkami:';
$lang['ref_hidden']  = 'Niektoré referencie sú na stránky pre ktoré nemáte právo na čítanie';

$lang['hits']       = '- počet výskytov';
$lang['quickhits']  = 'Zodpovedajúce stránky';
$lang['toc']        = 'Obsah';
$lang['current']    = 'aktualné';
$lang['yours']      = 'Vaša verzia';
$lang['diff']       = 'zobrazit rozdiely voči aktuálnej verzii';
$lang['line']       = 'Riadok';
$lang['breadcrumb'] = 'História';
$lang['youarehere'] = 'Nachádzate sa';
$lang['lastmod']    = 'Posledná úprava';
$lang['by']         = 'od';
$lang['deleted']    = 'odstranené';
$lang['created']    = 'vytvorené';
$lang['restored']   = 'stará verzia bola obnovena';
$lang['summary']    = 'Komentár k úpravám';

$lang['mail_newpage'] = 'stránka pridaná:';
$lang['mail_changed'] = 'stránka zmenená:';
$lang['mail_new_user'] = 'Nový užívateľ:';

$lang['nosmblinks'] = 'Odkazovanie na zdielané prostriedky Windows funguje len v Internet Explorer.\nAj napriek tomu tento odkaz môžete skopírovat a vložit inde.';

$lang['qb_alert']   = 'Vložte prosím text, ktorý chcete formátovať.\nTen bude pridaný na koniec dokumentu.';
$lang['qb_bold']    = 'Tučné';
$lang['qb_italic']  = 'Kurzíva';
$lang['qb_underl']  = 'Podčiarknutie';
$lang['qb_code']    = 'Neformátovať (zdrojový kód)';
$lang['qb_strike']  = 'Prečiarknutie';
$lang['qb_h1']      = 'Nadpis 1. úrovne';
$lang['qb_h2']      = 'Nadpis 2. úrovne';
$lang['qb_h3']      = 'Nadpis 3. úrovne';
$lang['qb_h4']      = 'Nadpis 4. úrovne';
$lang['qb_h5']      = 'Nadpis 5. úrovne';
$lang['qb_link']    = 'Interný odkaz';
$lang['qb_extlink'] = 'Externý odkaz';
$lang['qb_hr']      = 'Horizontálna linka';
$lang['qb_ol']      = 'Číslovaný zoznam';
$lang['qb_ul']      = 'Nečíslovaný zoznam';
$lang['qb_media']   = 'Vložiť obrázky alebo iné súbory';
$lang['qb_sig']     = 'Vložiť podpis';
$lang['qb_smileys'] = 'Smajlíky';
$lang['qb_chars']   = 'Špeciálne znaky';

$lang['del_confirm']= 'Zmazať túto položku?';
$lang['admin_register']= 'Pridaj nového užívateľa';

$lang['spell_start'] = 'Skontrolovať pravopis';
$lang['spell_stop']  = 'Úprava výsledku';
$lang['spell_wait']  = 'Prosím čakajte...';
$lang['spell_noerr'] = 'Žiadne chyby nenájdené';
$lang['spell_nosug'] = 'Žiadne doporučenia';
$lang['spell_change']= 'Zmena';

$lang['metaedit']    = 'Upraviť metainformácie';
$lang['metasaveerr'] = 'Zápis metainformácií zlyhal';
$lang['metasaveok']  = 'Metainformácie uložené';
$lang['img_backto']  = 'Späť na';
$lang['img_title']   = 'Titul';
$lang['img_caption'] = 'Popis';
$lang['img_date']    = 'Dátum';
$lang['img_fname']   = 'Názov súboru';
$lang['img_fsize']   = 'Veľkosť';
$lang['img_artist']  = 'Fotograf';
$lang['img_copyr']   = 'Kopírovacie práva';
$lang['img_format']  = 'Formát';
$lang['img_camera']  = 'Fotoaparát';
$lang['img_keywords']= 'Klúčové slová';

$lang['subscribe_success']  = 'Pridané %s do zoznamu objednávok pre %s';
$lang['subscribe_error']    = 'Chyba pri pridaní %s do zoznamu objednávok pre %s';
$lang['subscribe_noaddress']= 'Nie je žiadna e-mailová adresa priradená k vašemu menu,nemôžte byť pridaný do zoznamu objednávok';
$lang['unsubscribe_success']= 'Odobrané %s zo zoznamu objednávok pre %s';
$lang['unsubscribe_error']  = 'Chaba pri odobraní %s zo zoznamu objednávok pre %s';

/* auth.class language support */
$lang['authmodfailed']   = 'Užívateľská autentifikácia nie je možná. Prosím informujte  správcu tohto systému.';
$lang['authtempfail']    = 'Užívateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrvá, prosím informujte správcu tohto systému.';

/* mysql.class language support */
$lang['noMySQL']         = "MySQL rozšírenie pre PHP nenájdené. Prosím informujte  správcu tohto systému.";
$lang['noDatabase']      = "MySQL: Nie je možné vstúpiť do databázy '%d'. Prosím informujte  správcu tohto systému.";
$lang['noConnect']       = "MySQL: Nie je možné pripojiť sa k '%u@%s'. Prosím informujte  správcu tohto systému.";
$lang['joinGroupFailed'] = "Účet pre '%u' nie je vytvorený, pretože nie je možné pridať ho do skupiny '%g'.";
$lang['modUserFailed']   = "Nie je možné meniť údaje o užívateľovi. Prosím informujte  správcu tohto systému.";

/* installer strings */
$lang['i_chooselang'] = 'Zvoľte váš jazyk';
$lang['i_installer']  = 'DokuWiki inštalátor';
$lang['i_wikiname']   = 'Názov Wiki';
$lang['i_enableacl']  = 'Aktivovať ACL (doporučené)';
$lang['i_superuser']  = 'Superužívateľ';
$lang['i_problems']   = 'Inštalátor narazil na nižšie uvedené problémy. Nemôžte pokračovať, pokým ich neodstránite.';
$lang['i_modified']   = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balíček, alebo preštudovať <a href="http://wiki.splitbrain.org/wiki:install"> inštalačné inštrukcie Dokuwiki</a>';
$lang['i_funcna']     = 'PHP funkcia <code>%s</code> nie je dostupná. Je možné, že ju z určitých dôvodov zablokoval váš poskytovateľ webhostingu?';
$lang['i_permfail']   = '<code>%s</code> nie je zapisovateľný pre DokuWiki. Musíte zmeniť prístupové práva pre tento adresár!';
$lang['i_confexists'] = '<code>%s</code> skutočne existuje';
$lang['i_writeerr']   = 'Nie je možné vytvoriť <code>%s</code>. Potrebujete skontrolovať prístupové práva pre adresár/súbor a vytvoriť ho manuálne.';
$lang['i_badhash']    = 'nerozpoznaný, alebo zmenený súbor dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']     = '<code>%s</code> - bola zadaná nesprávna, alebo žiadna hodnota';
$lang['i_success']    = 'Konfigurácia bola úspešne ukončená. Teraz môžte zmazať súbor install.php. Pokračujte vo
                       <a href="doku.php">vašej novej DokuWiki</a>.';
$lang['i_failure']    = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým ako budete môcť používať
                         <a href="doku.php">vašu novú DokuWiki</a>.';
$lang['i_policy']     = 'Počiatočná ACL politika';
$lang['i_pol0']       = 'Otvorená Wiki (čítanie, zápis a nahrávanie pre každého)';
$lang['i_pol1']       = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných užívateľov)';
$lang['i_pol2']       = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';

//Setup VIM: ex: et ts=2 enc=utf-8 :
